@@ -11,7 +11,8 @@ import qbittorrentapi
 import requests
 from packaging import version as version_parser
 from packaging.version import Version as VersionClass
-from qbittorrentapi import APINames, login_required, response_text
+from qbittorrentapi import APINames
+from qbittorrentapi.decorators import login_required, response_text
 
 from qBitrr.arss import ArrManager
 from qBitrr.bundled_data import patched_version
@@ -29,7 +30,7 @@ run_logs(logger)
 
 class qBitManager:
     min_supported_version = VersionClass("4.3.4")
-    soft_not_supported_supported_version = VersionClass("4.4")
+    soft_not_supported_supported_version = VersionClass("4.5")
     max_supported_version = VersionClass("4.5")
     _head_less_mode = False
 
@@ -52,7 +53,7 @@ class qBitManager:
         self._validated_version = False
         self.client = None
         self.current_qbit_version = None
-        if not (QBIT_DISABLED or SEARCH_ONLY):
+        if not any([QBIT_DISABLED, SEARCH_ONLY]):
             self.client = qbittorrentapi.Client(
                 host=self.qBit_Host,
                 port=self.qBit_Port,
@@ -77,7 +78,7 @@ class qBitManager:
         self.child_processes = []
         self.ffprobe_downloader = FFprobeDownloader()
         try:
-            if not (SEARCH_ONLY or QBIT_DISABLED):
+            if not any([QBIT_DISABLED, SEARCH_ONLY]):
                 self.ffprobe_downloader.update()
         except Exception as e:
             self.logger.error(
@@ -89,10 +90,12 @@ class qBitManager:
     def _version_validator(self):
         if self.min_supported_version <= self.current_qbit_version < self.max_supported_version:
             if self.soft_not_supported_supported_version <= self.current_qbit_version:
-                self.logger.warning("Current qBitTorrent version is not fully supported: %s, "
-                                    "historically there's been some issued with qBitTorrent 4.4+ and "
-                                    "qBitrr worked best with 4.3.9",
-                                    self.current_qbit_version, )
+                self.logger.warning(
+                    "Current qBitTorrent version is not fully supported: %s, "
+                    "historically there's been some issued with qBitTorrent 4.4+ and "
+                    "qBitrr worked best with 4.3.9",
+                    self.current_qbit_version,
+                )
             elif self._validated_version:
                 self.logger.hnotice(
                     "Current qBitTorrent version is supported: %s",
